@@ -1,6 +1,7 @@
 #! /bin/sh
 # check script for GNU ed - The GNU line editor
-# Copyright (C) 2006, 2007, 2008, 2009, 2010 Free Software Foundation, Inc.
+# Copyright (C) 2006, 2007, 2008, 2009, 2010, 2011, 2012
+# Free Software Foundation, Inc.
 #
 # This script is free software; you have unlimited permission
 # to copy, distribute and modify it.
@@ -53,11 +54,14 @@ for i in *.err ; do
 done
 
 
+cd "${objdir}"/tmp
+fail=0
+
+printf "testing ed-%s...\n" "$2"
+
 # Run the .ed and .red scripts just generated
 # and compare their output against the .r and .pr files, which contain
 # the correct output.
-printf "testing ed-%s...\n" "$2"
-cd "${objdir}"/tmp
 
 # Run the *.red scripts first, since these don't generate output;
 # they exit with non-zero status
@@ -98,9 +102,12 @@ for i in *.ed ; do
 done > scripts.ck 2>&1
 
 grep '\*\*\*' *.ck | sed 's/^[^*]*//'
-if grep '\*\*\*' *.ck > /dev/null ; then
-	exit 127
-else
+grep '\*\*\*' *.ck > /dev/null && fail=127
+
+if [ ${fail} = 0 ] ; then
 	echo "tests completed successfully."
 	cd "${objdir}" && rm -r tmp
+else
+	echo "tests failed."
 fi
+exit ${fail}
